#!/bin/sh
echo "Installing midentd..."
touch /var/log/midentd.log
chown nobody /var/log/midentd.log
echo "/var/log/midentd.log created and chowned to nobody"
cp -v midentd midentd.logcycle /usr/local/sbin

if [ -d /etc/xinetd ]; then
	cp -v midentd.xinetd /etc/xinetd/midentd
elif [ -d /etc/xinetd.d ]; then
	cp -v midentd.xinetd /etc/xinetd.d/midentd
fi

mkdir /usr/doc/midentd
cp -v CHANGELOG README COPYING /usr/doc/midentd
echo
echo "Now, edit /etc/inetd.conf (or /etc/xinetd.d/midentd), and perhaps add"
echo "midentd.logcycle to roots crontab."
echo "Or, in case you want to use midentd as a standalone daemon, put"
echo "\"/usr/local/sbin/midentd -u nobody\" into on of your startup scripts"
